@@ -1,11 +1,14 @@
 import platform
 import sqlite3
-from PyQt5 import QtGui, QtWidgets, QtCore
-from PyQt5.QtCore import pyqtSignal as Signal, pyqtSlot as Slot
-from PyQt5.QtCore import QUrl
-from PyQt5.QtGui import QIcon
-from PyQt5.QtWebEngineWidgets import QWebEngineView, QWebEngineSettings
-from PyQt5.QtWidgets import QTabWidget, QApplication, QInputDialog, QFileDialog, QPushButton
+import threading
+import time
+
+from PyQt6 import QtGui, QtWidgets, QtCore
+from PyQt6.QtCore import pyqtSignal as Signal, pyqtSlot as Slot, Qt
+from PyQt6.QtCore import QUrl
+from PyQt6.QtGui import QIcon, QPalette, QColor
+from PyQt6.QtWebEngineWidgets import QWebEngineView
+from PyQt6.QtWidgets import QTabWidget, QApplication, QInputDialog, QFileDialog, QPushButton, QStyle
 
 # if platform.system() == "Linux":
 #     try:
@@ -39,12 +42,44 @@ except:
     pass
 
 
+class WizardWebssh(object):
+    """ Threading example class
+    The run() method will be started and it will run in the background
+    until the application exits.
+    """
+
+    def __init__(self, interval=1):
+        """ Constructor
+        :type interval: int
+        :param interval: Check interval, in seconds
+        """
+        self.interval = interval
+
+        thread = threading.Thread(target=self.run, args=())
+        thread.daemon = True  # Daemonize thread
+        thread.start()  # Start the execution
+
+    def run(self):
+        """ Method that runs forever """
+        while True:
+            # Start WebSSH Service in background.
+            print('Starting SSH websocket server in the background')
+            import asyncio
+
+            asyncio.set_event_loop(asyncio.new_event_loop())
+            from wizardwebssh.main import main as wssh
+            wssh()
+            print('Stopped SSH websocket server in the background')
+            QApplication.processEvents()
+            time.sleep(self.interval)
+
+
 class TabbedTerminal(QTabWidget):
     def __init__(self, parent=None):
         super(TabbedTerminal, self).__init__(parent)
 
         self.setDocumentMode(True)
-        self.setTabPosition(QTabWidget.South)
+        self.setTabPosition(QTabWidget.TabPosition.South)
         self._new_button = QPushButton(self)
         self._new_button.setText("New SSH Session")
         self._new_button.clicked.connect(self.add_new_tab)
@@ -72,6 +107,7 @@ class TabbedTerminal(QTabWidget):
 
         browser = QWebEngineView()
         self.webSettings = browser.settings()
+        style = self.style()
         # self.webSettings.setAttribute(QWebEngineSettings.PluginsEnabled, True)
         # self.webSettings.setAttribute(QWebEngineSettings.JavascriptEnabled, True)
         # self.webSettings.setAttribute(QWebEngineSettings.LocalStorageEnabled, True)
@@ -97,7 +133,11 @@ class TabbedTerminal(QTabWidget):
                                      self.setTabText(i, browser.page().title()))
         browser.titleChanged.connect(lambda _, i=i, browser=browser:
                                      self.setTabToolTip(i, browser.page().title()))
-        browser.loadFinished.connect(self.on_load_finished)
+        browser.titleChanged.connect(lambda _, i=i, browser=browser: self.setTabIcon(i, QtGui.QIcon(
+            style.standardIcon(QStyle.StandardPixmap.SP_MessageBoxCritical))) if (
+                    "WizardWebSSH" in browser.page().title()) else self.setTabIcon(i, QtGui.QIcon(
+            style.standardIcon(QStyle.StandardPixmap.SP_ComputerIcon))))
+        # browser.loadFinished.connect(self.on_load_finished)
 
     def tab_open_doubleclick(self, i):
         if i == -1:  # No tab under the click
@@ -148,12 +188,37 @@ class TabbedTerminal(QTabWidget):
 if __name__ == "__main__":
     import sys
 
+    wizardwebssh_service = WizardWebssh()
+    time.sleep(.300)
     # sys.argv.append("--remote-debugging-port=8000")
     # sys.argv.append("--disable-web-security")
     app = QApplication(sys.argv)
-    app.setApplicationName("Wizard Assistant SSH")
-    app.setOrganizationName("Wizard Assistant")
+    QApplication.setStyle("Fusion")
+    #
+    # # Now use a palette to switch to dark colors:
+    dark_palette = QPalette()
+    dark_palette.setColor(QPalette.ColorRole.Window, QColor(53, 53, 53))
+    dark_palette.setColor(QPalette.ColorRole.WindowText, Qt.GlobalColor.white)
+    dark_palette.setColor(QPalette.ColorRole.Base, QColor(35, 35, 35))
+    dark_palette.setColor(QPalette.ColorRole.AlternateBase, QColor(53, 53, 53))
+    dark_palette.setColor(QPalette.ColorRole.ToolTipBase, QColor(25, 25, 25))
+    dark_palette.setColor(QPalette.ColorRole.ToolTipText, Qt.GlobalColor.white)
+    dark_palette.setColor(QPalette.ColorRole.Text, Qt.GlobalColor.white)
+    dark_palette.setColor(QPalette.ColorRole.Button, QColor(53, 53, 53))
+    dark_palette.setColor(QPalette.ColorRole.ButtonText, Qt.GlobalColor.white)
+    dark_palette.setColor(QPalette.ColorRole.BrightText, Qt.GlobalColor.red)
+    dark_palette.setColor(QPalette.ColorRole.Link, QColor(42, 130, 218))
+    dark_palette.setColor(QPalette.ColorRole.Highlight, QColor(42, 130, 218))
+    dark_palette.setColor(QPalette.ColorRole.HighlightedText, QColor(35, 35, 35))
+    dark_palette.setColor(QPalette.ColorGroup.Active, QPalette.ColorRole.Button, QColor(53, 53, 53))
+    dark_palette.setColor(QPalette.ColorGroup.Disabled, QPalette.ColorRole.ButtonText, Qt.GlobalColor.darkGray)
+    dark_palette.setColor(QPalette.ColorGroup.Disabled, QPalette.ColorRole.WindowText, Qt.GlobalColor.darkGray)
+    dark_palette.setColor(QPalette.ColorGroup.Disabled, QPalette.ColorRole.Text, Qt.GlobalColor.darkGray)
+    dark_palette.setColor(QPalette.ColorGroup.Disabled, QPalette.ColorRole.Light, QColor(53, 53, 53))
+    QApplication.setPalette(dark_palette)
+    app.setApplicationName("WizardAssistantDesktop")
+    app.setOrganizationName("WizardAssistant")
     app.setOrganizationDomain("wizardassistant.com")
     win = TabbedTerminal()
     win.show()
-    app.exec_()
+    app.exec()
